/* Define this if your system supports it */
#undef _XOPEN_SOURCE

/* Define if you have the <errno.h> header file.  */
#undef HAVE_SYS_SELECT_H

/* Define if your system lacks `fd_set' */
#undef NO_FD_SET

/* The name of the package */
#undef PACKAGE

/* The packages version */
#undef VERSION
